@@ -4,6 +4,8 @@
 #include <functional>
 #include <string>
 
+#include "filepath.h"
+
 namespace podboat {
 
 enum class DlStatus {
@@ -22,7 +24,6 @@ enum class DlStatus {
 class Download {
 public:
 	explicit Download(std::function<void()> cb_require_view_update);
-	~Download();
 	double percents_finished() const;
 	const std::string status_text() const;
 	DlStatus status() const
@@ -33,10 +34,10 @@ public:
 	{
 		return msg;
 	}
-	const std::string filename() const;
-	const std::string basename() const;
-	const std::string url() const;
-	void set_filename(const std::string& str);
+	newsboat::Filepath filename() const;
+	newsboat::Filepath basename() const;
+	const std::string& url() const;
+	void set_filename(const newsboat::Filepath& str);
 	void set_url(const std::string& url);
 	void set_progress(double downloaded, double total);
 	void set_status(DlStatus dls, const std::string& msg_ = {});
@@ -54,7 +55,7 @@ public:
 	}
 
 private:
-	std::string fn;
+	newsboat::Filepath fn;
 	std::string url_;
 	DlStatus download_status;
 	std::string msg;
