@@ -1,10 +1,11 @@
 #ifndef NEWSBOAT_FILE_SYSTEM_H_
 #define NEWSBOAT_FILE_SYSTEM_H_
 
+#include <optional>
 #include <string>
 #include <sys/stat.h>
 
-#include "3rd-party/optional.hpp"
+#include "filepath.h"
 
 namespace newsboat {
 
@@ -30,12 +31,12 @@ FileType mode_to_filetype(mode_t mode);
 char filetype_to_char(FileType type);
 
 /// Get a suffix that `ls --classify` adds to names with given `mode`.
-nonstd::optional<char> mode_suffix(mode_t mode);
+std::optional<char> mode_suffix(mode_t mode);
 
 /// An entry in a listing, e.g. a file, a directory or suchlike.
 struct FileSystemEntry {
 	FileType filetype;
-	std::string name;
+	Filepath name;
 };
 
 /// The name of the user with a given UID, padded on the right to the width of
