@@ -15,12 +15,12 @@ public:
 	~SelectFormAction() override = default;
 	void prepare() override;
 	void init() override;
-	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
+	std::vector<KeyMapHintEntry> get_keymap_hint() const override;
 	void set_selected_value(const std::string& new_value)
 	{
 		value = new_value;
 	}
-	std::string get_selected_value()
+	const std::string& get_selected_value()
 	{
 		return value;
 	}
@@ -54,7 +54,6 @@ private:
 	bool process_operation(Operation op,
 		const std::vector<std::string>& args,
 		BindingType bindingType = BindingType::BindKey) override;
-	bool quit;
 	bool is_first_draw;
 	SelectionType type;
 	std::string value;
