@@ -7,7 +7,7 @@
 
 namespace newsboat {
 
-ReloadThread::ReloadThread(Controller* c, ConfigContainer& cf)
+ReloadThread::ReloadThread(Controller& c, ConfigContainer& cf)
 	: ctrl(c)
 	, oldtime(0)
 	, waittime_sec(0)
@@ -37,13 +37,12 @@ void ReloadThread::operator()()
 
 		if (cfg.get_configvalue_as_bool("auto-reload")) {
 			if (suppressed_first) {
-				ctrl->get_reloader()->start_reload_all_thread();
+				ctrl.get_reloader()->start_reload_all_thread();
 			} else {
 				suppressed_first = true;
 				if (!cfg.get_configvalue_as_bool(
 						"suppress-first-reload")) {
-					ctrl->get_reloader()
-					->start_reload_all_thread();
+					ctrl.get_reloader()->start_reload_all_thread();
 				}
 			}
 		} else {
