@@ -68,10 +68,6 @@ RssFeed::RssFeed(Cache* c, const std::string& rssurl)
 	}
 }
 
-RssFeed::~RssFeed()
-{
-}
-
 unsigned int RssFeed::unread_item_count() const
 {
 	std::lock_guard<std::mutex> lock(item_mutex);
@@ -164,7 +160,7 @@ std::shared_ptr<RssItem> RssFeed::get_item_by_guid_unlocked(
 	return std::shared_ptr<RssItem>(new RssItem(ch));
 }
 
-nonstd::optional<std::string> RssFeed::attribute_value(const std::string&
+std::optional<std::string> RssFeed::attribute_value(const std::string&
 	attribname) const
 {
 	if (attribname == "feedtitle") {
@@ -203,7 +199,7 @@ nonstd::optional<std::string> RssFeed::attribute_value(const std::string&
 		}
 		return "0";
 	}
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
 void RssFeed::update_items(std::vector<std::shared_ptr<RssFeed>> feeds)
