@@ -2,13 +2,12 @@
 
 #include <algorithm>
 #include <cassert>
-#include <sstream>
 #include <string>
 
 #include "config.h"
 #include "controller.h"
 #include "fmtstrformatter.h"
-#include "listformatter.h"
+#include "stflrichtext.h"
 #include "strprintf.h"
 #include "utils.h"
 #include "view.h"
@@ -22,11 +21,10 @@ namespace newsboat {
  * a few places.
  */
 
-SelectFormAction::SelectFormAction(View* vv,
+SelectFormAction::SelectFormAction(View& vv,
 	std::string formstr,
 	ConfigContainer* cfg)
 	: FormAction(vv, formstr, cfg)
-	, quit(false)
 	, is_first_draw(true)
 	, type(SelectionType::TAG)
 	, value("")
@@ -34,8 +32,6 @@ SelectFormAction::SelectFormAction(View* vv,
 {
 }
 
-SelectFormAction::~SelectFormAction() {}
-
 void SelectFormAction::handle_cmdline(const std::string& cmd)
 {
 	unsigned int idx = 0;
@@ -52,9 +48,10 @@ void SelectFormAction::handle_cmdline(const std::string& cmd)
 }
 
 bool SelectFormAction::process_operation(Operation op,
-	bool /* automatic */,
-	std::vector<std::string>* /* args */)
+	const std::vector<std::string>& /* args */,
+	BindingType /*bindingType*/)
 {
+	bool quit = false;
 	bool hardquit = false;
 	switch (op) {
 	case OP_PREV:
@@ -122,18 +119,15 @@ bool SelectFormAction::process_operation(Operation op,
 	}
 	break;
 	default:
-		if (handle_list_operations(tags_list, op)) {
-			break;
-		}
-		break;
+		return handle_list_operations(tags_list, op);
 	}
 
 	if (hardquit) {
-		while (v->formaction_stack_size() > 0) {
-			v->pop_current_formaction();
+		while (v.formaction_stack_size() > 0) {
+			v.pop_current_formaction();
 		}
 	} else if (quit) {
-		v->pop_current_formaction();
+		v.pop_current_formaction();
 	}
 	return true;
 }
@@ -142,35 +136,41 @@ void SelectFormAction::prepare()
 	if (do_redraw) {
 		update_heading();
 
-		ListFormatter listfmt;
-		unsigned int i = 0;
 		const auto selecttag_format = cfg->get_configvalue("selecttag-format");
-		const auto width = tags_list.get_width();
+
+		std::uint32_t num_lines = 0;
+		std::function<StflRichText(std::uint32_t, std::uint32_t)> render_line;
 
 		switch (type) {
 		case SelectionType::TAG:
-			for (const auto& tag : tags) {
-				listfmt.add_line(
-					utils::quote_for_stfl(
-						format_line(selecttag_format,
-							tag,
-							i + 1,
-							width)));
-				i++;
-			}
+			num_lines = tags.size();
+			render_line = [this, selecttag_format](std::uint32_t line,
+			std::uint32_t width) -> StflRichText {
+				const auto& tag = tags[line];
+				return StflRichText::from_plaintext(
+					format_line(selecttag_format,
+						tag,
+						line + 1,
+						width));
+			};
 			break;
 		case SelectionType::FILTER:
-			for (const auto& filter : filters) {
-				std::string tagstr = strprintf::fmt(
-						"%4u  %s", i + 1, filter.name);
-				listfmt.add_line(utils::quote_for_stfl(tagstr));
-				i++;
-			}
+			num_lines = filters.size();
+			render_line = [this](std::uint32_t line, std::uint32_t width) -> StflRichText {
+				(void)width;
+				const auto& filter = filters[line];
+				return StflRichText::from_plaintext(
+					strprintf::fmt(
+						"%4u  %s",
+						line + 1,
+						filter.name));
+			};
 			break;
 		default:
 			assert(0);
 		}
-		tags_list.stfl_replace_lines(listfmt);
+
+		tags_list.invalidate_list_content(num_lines, render_line);
 
 		if (is_first_draw && type == SelectionType::TAG && !value.empty()) {
 			const auto it = std::find(tags.begin(), tags.end(), value);
@@ -188,7 +188,6 @@ void SelectFormAction::prepare()
 void SelectFormAction::init()
 {
 	do_redraw = true;
-	quit = false;
 
 	recalculate_widget_dimensions();
 
@@ -202,7 +201,7 @@ std::string SelectFormAction::format_line(const std::string& selecttag_format,
 {
 	FmtStrFormatter fmt;
 
-	const auto feedcontainer = v->get_ctrl()->get_feedcontainer();
+	const auto feedcontainer = v.get_ctrl().get_feedcontainer();
 
 	const auto total_feeds = feedcontainer->get_feed_count_per_tag(tag);
 	const auto unread_feeds =
@@ -243,10 +242,10 @@ void SelectFormAction::update_heading()
 	default:
 		assert(0); // should never happen
 	}
-	set_value("head", title);
+	set_title(title);
 }
 
-const std::vector<KeyMapHintEntry>& SelectFormAction::get_keymap_hint() const
+std::vector<KeyMapHintEntry> SelectFormAction::get_keymap_hint() const
 {
 	static const std::vector<KeyMapHintEntry> hints_tag = {{OP_QUIT, _("Cancel")},
 		{OP_OPEN, _("Select Tag")}
