@@ -16,7 +16,7 @@ using namespace newsboat;
 // Forks and calls FsLock::try_lock() in the child process.
 class LockProcess {
 public:
-	explicit LockProcess(const std::string& lock_location)
+	explicit LockProcess(const Filepath& lock_location)
 	{
 		sem_start = sem_open(sem_start_name, O_CREAT, 0644, 0);
 		sem_stop = sem_open(sem_stop_name, O_CREAT, 0644, 0);
@@ -76,9 +76,8 @@ TEST_CASE("try_lock() returns an error if lock-file permissions or location are
 
 	GIVEN("An invalid lock location") {
 		const test_helpers::TempDir test_directory;
-		const std::string non_existing_dir = test_directory.get_path() +
-			"does-not-exist/";
-		const std::string lock_location = non_existing_dir + "lockfile";
+		const auto non_existing_dir = test_directory.get_path().join("does-not-exist"_path);
+		const auto lock_location = non_existing_dir.join("lockfile"_path);
 
 		THEN("try_lock() will fail and return pid == 0") {
 			FsLock lock;
@@ -94,7 +93,8 @@ TEST_CASE("try_lock() returns an error if lock-file permissions or location are
 
 	GIVEN("A lock file which does not grant write access") {
 		const test_helpers::TempFile lock_location;
-		const int fd = ::open(lock_location.get_path().c_str(), O_RDWR | O_CREAT, 0400);
+		const int fd = ::open(lock_location.get_path().to_locale_string().c_str(),
+				O_RDWR | O_CREAT, 0400);
 		::close(fd);
 
 		THEN("try_lock() will fail and return pid == 0") {
@@ -143,7 +143,7 @@ TEST_CASE("try_lock() succeeds if lock file location is valid and not locked by
 	REQUIRE(lock.try_lock(lock_location.get_path(), pid, error_message));
 
 	SECTION("The lock file exists after a call to try_lock()") {
-		REQUIRE(0 == ::access(lock_location.get_path().c_str(), F_OK));
+		REQUIRE(0 == ::access(lock_location.get_path().to_locale_string().c_str(), F_OK));
 	}
 
 	SECTION("Calling try_lock() a second time for the same location succeeds") {
@@ -153,10 +153,10 @@ TEST_CASE("try_lock() succeeds if lock file location is valid and not locked by
 	SECTION("Calling try_lock() a second time with a different location succeeds and cleans up old lock file") {
 		const test_helpers::TempFile new_lock_location;
 
-		REQUIRE(0 == ::access(lock_location.get_path().c_str(), F_OK));
+		REQUIRE(0 == ::access(lock_location.get_path().to_locale_string().c_str(), F_OK));
 		REQUIRE(lock.try_lock(new_lock_location.get_path(), pid, error_message));
-		REQUIRE(0 != ::access(lock_location.get_path().c_str(), F_OK));
-		REQUIRE(0 == ::access(new_lock_location.get_path().c_str(), F_OK));
+		REQUIRE(0 != ::access(lock_location.get_path().to_locale_string().c_str(), F_OK));
+		REQUIRE(0 == ::access(new_lock_location.get_path().to_locale_string().c_str(), F_OK));
 	}
 }
 
